Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2477)

Unified Diff: chrome/browser/sync/profile_sync_components_factory.h

Issue 10698014: [Sync] Rename csync namespace to syncer (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Address comments Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/profile_sync_components_factory.h
diff --git a/chrome/browser/sync/profile_sync_components_factory.h b/chrome/browser/sync/profile_sync_components_factory.h
index 8abd964c9e46364f5ab1345e4625cfa249a5d968..bba73b0ddc965fbfc85585db9ef41d0296376b93 100644
--- a/chrome/browser/sync/profile_sync_components_factory.h
+++ b/chrome/browser/sync/profile_sync_components_factory.h
@@ -27,7 +27,7 @@ class SyncBackendHost;
class DataTypeErrorHandler;
}
-namespace csync {
+namespace syncer {
class SyncableService;
}
@@ -45,7 +45,7 @@ class ProfileSyncComponentsFactory {
//
// Note: This interface is deprecated in favor of the SyncableService API.
// New datatypes that do not live on the UI thread should directly return a
// weak pointer to a csync::SyncableService. All others continue to return
// SyncComponents. It is safe to assume that the factory methods below are
// called on the same thread in which the datatype resides.
//
@@ -76,7 +76,7 @@ class ProfileSyncComponentsFactory {
virtual browser_sync::GenericChangeProcessor* CreateGenericChangeProcessor(
ProfileSyncService* profile_sync_service,
browser_sync::DataTypeErrorHandler* error_handler,
- const base::WeakPtr<csync::SyncableService>& local_service) = 0;
+ const base::WeakPtr<syncer::SyncableService>& local_service) = 0;
virtual browser_sync::SharedChangeProcessor*
CreateSharedChangeProcessor() = 0;
@@ -84,7 +84,7 @@ class ProfileSyncComponentsFactory {
// Returns a weak pointer to the syncable service specified by |type|.
// Weak pointer may be unset if service is already destroyed.
// Note: Should only be called on the same thread on which a datatype resides.
- virtual base::WeakPtr<csync::SyncableService> GetSyncableServiceForType(
+ virtual base::WeakPtr<syncer::SyncableService> GetSyncableServiceForType(
syncable::ModelType type) = 0;
// Legacy datatypes that need to be converted to the SyncableService API.
@@ -45,7 +45,7 @@ class ProfileSyncComponentsFactory {
// Note: This interface is deprecated in favor of the SyncableService API.
// New datatypes that do not live on the UI thread should directly return a
- // weak pointer to a csync::SyncableService. All others continue to return
+ // weak pointer to a syncer::SyncableService. All others continue to return
// SyncComponents. It is safe to assume that the factory methods below are
// called on the same thread in which the datatype resides.

Powered by Google App Engine
This is Rietveld 408576698